@@ -1,5 +1,7 @@
 ANOMgen <- function(mu, n=NULL, gm=NULL, lo, up, names=NULL, alternative="two.sided",
-                    xlabel="Group", ylabel="Endpoint", printn=T, p=NULL, bg="white"){
+                    xlabel="Group", ylabel="Endpoint", printn=TRUE, p=NULL, bg="white",
+                    bgrid=TRUE, axlsize=18, axtsize=25, npsize=5, psize=5, lwidth=1,
+                    dlstyle="dashed", fillcol="darkgray"){
   
   if(is.null(gm)){
     gm <- weighted.mean(mu, n)
@@ -23,15 +25,15 @@ ANOMgen <- function(mu, n=NULL, gm=NULL, lo, up, names=NULL, alternative="two.si
   }
   
   if(is.null(n)){
-    printn <- F
+    printn <- FALSE
   }
   
   if(!(is.null(p))){
-    printp <- T
+    printp <- TRUE
     p <- paste("p=", round(p, 3), sep="")
     p[p=="p=0"] <- "p<0.001"
   }else{
-    printp <- F
+    printp <- FALSE
   }
   
   dir <- match.arg(alternative, choices=c("two.sided", "greater", "less"))
@@ -45,14 +47,14 @@ ANOMgen <- function(mu, n=NULL, gm=NULL, lo, up, names=NULL, alternative="two.si
   ldl <- gm - abs((mu - gm) - up)
   udl <- gm + abs((mu - gm) - lo)
   
-  if(printp==T){
-    if(printn==T){
+  if(printp==TRUE){
+    if(printn==TRUE){
       set <- data.frame(mu, gm, lo, up, ldl, udl, grp, grpf, names, n, p)
     }else{
       set <- data.frame(mu, gm, lo, up, ldl, udl, grp, grpf, names, p)
     }
   }else{
-    if(printn==T){
+    if(printn==TRUE){
       set <- data.frame(mu, gm, lo, up, ldl, udl, grp, grpf, names, n)
     }else{
       set <- data.frame(mu, gm, lo, up, ldl, udl, grp, grpf, names)
@@ -67,6 +69,12 @@ ANOMgen <- function(mu, n=NULL, gm=NULL, lo, up, names=NULL, alternative="two.si
     back <- theme_gray()
   }
   
+  if(bgrid==TRUE){
+    bgr <- element_line()
+  }else{
+    bgr <- element_blank()
+  }
+  
   if(dir=="two.sided"){
     
     basic <- ggplot(set, aes(x=grpf, y=mu)) +
@@ -74,19 +82,22 @@ ANOMgen <- function(mu, n=NULL, gm=NULL, lo, up, names=NULL, alternative="two.si
       xlab(xlabel) +
       ylab(ylabel) +
       geom_rect(aes(xmin=grp-0.5, xmax=grp+0.5, ymin=ldl, ymax=udl),
-                alpha=0.5, fill="darkgray", linetype=0) +
-      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=udl, yend=udl), size=1, linetype=2) +
-      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=ldl, yend=ldl), size=1, linetype=2) +
-      geom_segment(aes(x=0.5, xend=max(grp)+0.5, y=gm, yend=gm), size=1.5) +
-      geom_segment(aes(x=grp, xend=grp, y=mu, yend=gm), size=1) +
-      geom_point(size=5) +
+                alpha=0.5, fill=fillcol, linetype=0) +
+      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=udl, yend=udl), size=lwidth, linetype=dlstyle) +
+      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=ldl, yend=ldl), size=lwidth, linetype=dlstyle) +
+      geom_segment(aes(x=0.5, xend=max(grp)+0.5, y=gm, yend=gm), size=lwidth) +
+      geom_segment(aes(x=grp, xend=grp, y=mu, yend=gm), size=lwidth) +
+      geom_point(size=psize) +
       annotate("text", label="LDL", x=max(grp)+0.4, y=ldl[max(grp)], size=4, vjust=1.5) +
       annotate("text", label="UDL", x=max(grp)+0.4, y=udl[max(grp)], size=4, vjust=-0.75) +
       ylim(min(min(mu), min(ldl))-(gm-min(min(mu), min(ldl)))/5,
            max(max(mu), max(udl))+(max(max(mu), max(udl))-gm)/5) +
       back +
-      theme(axis.text.x=element_text(size=18), axis.text.y=element_text(size=18),
-            axis.title.x=element_text(size=25), axis.title.y=element_text(size=25))
+      theme(axis.text.x=element_text(size=axlsize),
+            axis.text.y=element_text(size=axlsize),
+            axis.title.x=element_text(size=axtsize),
+            axis.title.y=element_text(size=axtsize),
+            panel.grid=bgr)
     
   }
   
@@ -97,17 +108,20 @@ ANOMgen <- function(mu, n=NULL, gm=NULL, lo, up, names=NULL, alternative="two.si
       xlab(xlabel) +
       ylab(ylabel) +
       geom_rect(aes(xmin=grp-0.5, xmax=grp+0.5, ymin=ldl, ymax=udl),
-                alpha=0.5, fill="darkgray", linetype=0) +
-      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=udl, yend=udl), size=1, linetype=2) +
-      geom_segment(aes(x=0.5, xend=max(grp)+0.5, y=gm, yend=gm), size=1.5) +
-      geom_segment(aes(x=grp, xend=grp, y=mu, yend=gm), size=1) +
-      geom_point(size=5) +
+                alpha=0.5, fill=fillcol, linetype=0) +
+      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=udl, yend=udl), size=lwidth, linetype=dlstyle) +
+      geom_segment(aes(x=0.5, xend=max(grp)+0.5, y=gm, yend=gm), size=lwidth) +
+      geom_segment(aes(x=grp, xend=grp, y=mu, yend=gm), size=lwidth) +
+      geom_point(size=psize) +
       annotate("text", label="UDL", x=max(grp)+0.4, y=udl[max(grp)], size=4, vjust=-0.75) +
       ylim((min(mu)-(gm-min(mu))/5)[1],
            (max(max(mu), max(udl))+(max(max(mu), max(udl))-gm)/5)[1]) +
       back +
-      theme(axis.text.x=element_text(size=18), axis.text.y=element_text(size=18),
-            axis.title.x=element_text(size=25), axis.title.y=element_text(size=25))
+      theme(axis.text.x=element_text(size=axlsize),
+            axis.text.y=element_text(size=axlsize),
+            axis.title.x=element_text(size=axtsize),
+            axis.title.y=element_text(size=axtsize),
+            panel.grid=bgr)
     
   }
   
@@ -118,40 +132,43 @@ ANOMgen <- function(mu, n=NULL, gm=NULL, lo, up, names=NULL, alternative="two.si
       xlab(xlabel) +
       ylab(ylabel) +
       geom_rect(aes(xmin=grp-0.5, xmax=grp+0.5, ymin=ldl, ymax=udl),
-                alpha=0.5, fill="darkgray", linetype=0) +
-      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=ldl, yend=ldl), size=1, linetype=2) +
-      geom_segment(aes(x=0.5, xend=max(grp)+0.5, y=gm, yend=gm), size=1.5) +
-      geom_segment(aes(x=grp, xend=grp, y=mu, yend=gm), size=1) +
-      geom_point(size=5) +
+                alpha=0.5, fill=fillcol, linetype=0) +
+      geom_segment(aes(x=grp-0.5, xend=grp+0.5, y=ldl, yend=ldl), size=lwidth, linetype=dlstyle) +
+      geom_segment(aes(x=0.5, xend=max(grp)+0.5, y=gm, yend=gm), size=lwidth) +
+      geom_segment(aes(x=grp, xend=grp, y=mu, yend=gm), size=lwidth) +
+      geom_point(size=psize) +
       annotate("text", label="LDL", x=max(grp)+0.4, y=ldl[max(grp)], size=4, vjust=1.5) +
       ylim((min(min(mu), min(ldl))-(gm-min(min(mu), min(ldl)))/5)[1],
            (max(mu)+(max(mu)-gm)/5)[1]) +
       back +
-      theme(axis.text.x=element_text(size=18), axis.text.y=element_text(size=18),
-            axis.title.x=element_text(size=25), axis.title.y=element_text(size=25))
+      theme(axis.text.x=element_text(size=axlsize),
+            axis.text.y=element_text(size=axlsize),
+            axis.title.x=element_text(size=axtsize),
+            axis.title.y=element_text(size=axtsize),
+            panel.grid=bgr)
     
   }
   
   if(dir=="greater"){
-    npart <- geom_text(aes(y=min(mu), label=paste("n=", n, sep="")), vjust=3, size=5)
+    npart <- geom_text(aes(y=min(mu), label=paste("n=", n, sep="")), vjust=3, size=npsize)
   }else{
-    npart <- geom_text(aes(y=min(min(mu), min(ldl)), label=paste("n=", n, sep="")), vjust=3, size=5)
+    npart <- geom_text(aes(y=min(min(mu), min(ldl)), label=paste("n=", n, sep="")), vjust=3, size=npsize)
   }
   
   if(dir=="less"){
-    ppart <- geom_text(aes(y=max(mu), label=p), vjust=-2, size=5)
+    ppart <- geom_text(aes(y=max(mu), label=p), vjust=-2, size=npsize)
   }else{
-    ppart <- geom_text(aes(y=max(max(mu), max(udl)), label=p), vjust=-2, size=5)
+    ppart <- geom_text(aes(y=max(max(mu), max(udl)), label=p), vjust=-2, size=npsize)
   }
   
-  if(printn==T){
-    if(printp==T){
+  if(printn==TRUE){
+    if(printp==TRUE){
       chart <- basic + npart + ppart
     }else{
       chart <- basic + npart
     }
   }else{ 
-    if(printp==T){
+    if(printp==TRUE){
       chart <- basic + ppart
     }else{
       chart <- basic
